==> haskell-conversion-bytestring-1.0.1-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-conversion-bytestring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 conversion-bytestring
version:              1.0.1
visibility:           public
id:                   conversion-bytestring-1.0.1-CoJaLBQCWCl2XTlBMrUxDG
key:                  conversion-bytestring-1.0.1-CoJaLBQCWCl2XTlBMrUxDG
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/conversion-bytestring 
synopsis:             "Conversion" instances for the "bytestring" library
category:             Control, Data, Conversion
abi:                  20e4168956dd0d692b31783015476b26
exposed:              True
exposed-modules:      Conversion.ByteString
import-dirs:          /usr/lib/ghc-8.10.1/site-local/conversion-bytestring-1.0.1
library-dirs:         /usr/lib/ghc-8.10.1/site-local/conversion-bytestring-1.0.1
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.1/conversion-bytestring-1.0.1

hs-libraries:         HSconversion-bytestring-1.0.1-CoJaLBQCWCl2XTlBMrUxDG
depends:
    base-prelude-1.4-ABZOximOTQnEuKBtBaBHxC bytestring-0.10.10.0
    conversion-1.2.1-AtbOawn901AFmhF5YuB7Ds

haddock-interfaces:
    /usr/share/doc/haskell-conversion-bytestring/html/conversion-bytestring.haddock

haddock-html:         /usr/share/doc/haskell-conversion-bytestring/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conversion-bytestring-1.0.1-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-conversion-bytestring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 conversion-bytestring
version:              1.0.1
visibility:           public
id:                   conversion-bytestring-1.0.1-DFnVUs063IKI1CKe6P6wDf
key:                  conversion-bytestring-1.0.1-DFnVUs063IKI1CKe6P6wDf
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/conversion-bytestring 
synopsis:             "Conversion" instances for the "bytestring" library
category:             Control, Data, Conversion
abi:                  f5eb397fb37692daa9291b7b3da32fc6
exposed:              True
exposed-modules:      Conversion.ByteString
import-dirs:          /usr/lib/ghc-8.10.2/site-local/conversion-bytestring-1.0.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/conversion-bytestring-1.0.1
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.2/conversion-bytestring-1.0.1

hs-libraries:         HSconversion-bytestring-1.0.1-DFnVUs063IKI1CKe6P6wDf
depends:
    base-prelude-1.4-HdaTqh6hlYNGbCWV2trBTv bytestring-0.10.10.0
    conversion-1.2.1-Cue86SvBnrS8Z3RWwFhbOi

haddock-interfaces:
    /usr/share/doc/haskell-conversion-bytestring/html/conversion-bytestring.haddock

haddock-html:         /usr/share/doc/haskell-conversion-bytestring/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
